Crate linicon_theme[−][src]
Get the user’s current icon theme on Linux
There isn’t a unified standard for getting the current icon theme on Linux.
So linicon-theme attempts to check many places theme information might be
stored. See get_icon_theme for more details.
Example
use linicon_theme::get_icon_theme; println!("Your current icon theme is: {}", get_icon_theme().unwrap());
Enums
| Check | Select which theme store locations to check |
Functions
| get_icon_theme | Get the user’s current icon theme |
| get_icon_theme_order | The same as |